Index: FL/Enumerations.H
===================================================================
--- FL/Enumerations.H	(revision 10486)
+++ FL/Enumerations.H	(working copy)
@@ -27,7 +27,7 @@
  * in the current patch release of FLTK. ** Use for static builds only! **
  * For more info on this macro, see: http://fltk.org/cmp.php#FLTK_ABI_VERSION
  */
-//#define FLTK_ABI_VERSION 10303
+//#define FLTK_ABI_VERSION 10304
 
 #  include "Fl_Export.H"
 #  include "fl_types.h"
Index: FL/Fl_Tabs.H
===================================================================
--- FL/Fl_Tabs.H	(revision 10486)
+++ FL/Fl_Tabs.H	(working copy)
@@ -199,7 +199,12 @@
 	such as using the arrow keys while at the left or right end of the tabs.
 */
 class FL_EXPORT Fl_Tabs : public Fl_Group {
-  Fl_Widget *value_;
+#if FLTK_ABI_VERSION >= 10304
+  // NEW (nothing)
+#else
+  // OLD (maintained for ABI compat)
+  Fl_Widget *value_;	// NOTE: this member no longer used -- STR #3169
+#endif
   Fl_Widget *push_;
   int *tab_pos;		// array of x-offsets of tabs per child + 1
   int *tab_width;	// array of widths of tabs per child + 1
Index: fluid/CodeEditor.cxx
===================================================================
--- fluid/CodeEditor.cxx	(revision 10486)
+++ fluid/CodeEditor.cxx	(working copy)
@@ -179,7 +179,9 @@
         // Might be a keyword...
 	for (temp = text, bufptr = buf;
 	     (islower(*temp) || *temp == '_') && bufptr < (buf + sizeof(buf) - 1);
-	     *bufptr++ = *temp++);
+	     *bufptr++ = *temp++) {
+	  // nothing
+	}
 
         if (!islower(*temp) && *temp != '_') {
 	  *bufptr = '\0';
Index: src/Fl_Preferences.cxx
===================================================================
--- src/Fl_Preferences.cxx	(revision 10486)
+++ src/Fl_Preferences.cxx	(working copy)
@@ -955,6 +955,8 @@
 
 int Fl_Preferences::Node::lastEntrySet = -1;
 
+// THIS CODE CURRENTLY UNUSED -- STR# 3169
+#if 0
 // recursively create a path in the file system
 static char makePath( const char *path ) {
   if (access(path, 0)) {
@@ -974,6 +976,7 @@
   }
   return 1;
 }
+#endif
 
 #if 0
 // strip the filename and create a path
Index: src/Fl_Tabs.cxx
===================================================================
--- src/Fl_Tabs.cxx	(revision 10486)
+++ src/Fl_Tabs.cxx	(working copy)
@@ -461,6 +461,12 @@
   Fl_Group(X,Y,W,H,l)
 {
   box(FL_THIN_UP_BOX);
+#if FLTK_ABI_VERSION >= 10304
+  // NEW (nothing)
+#else
+  // OLD (init to prevent 'unused' warnings) -- STR #3169
+  value_ = 0;	// NOTE: this member unused -- STR #3169
+#endif
   push_ = 0;
   tab_pos = 0;
   tab_width = 0;
Index: src/Fl_Tree.cxx
===================================================================
--- src/Fl_Tree.cxx	(revision 10486)
+++ src/Fl_Tree.cxx	(working copy)
@@ -62,6 +62,7 @@
   }
 }
 
+#if 0		/* unused code -- STR #3169 */
 // INTERNAL: Recursively descend 'item's tree hierarchy
 //           accumulating total child 'count'
 //
@@ -72,6 +73,7 @@
   }
   return(count);
 }
+#endif
 
 /// Constructor.
 Fl_Tree::Fl_Tree(int X, int Y, int W, int H, const char *L) : Fl_Group(X,Y,W,H,L) { 
Index: src/Fl_cocoa.mm
===================================================================
--- src/Fl_cocoa.mm	(revision 10486)
+++ src/Fl_cocoa.mm	(working copy)
@@ -1108,7 +1108,7 @@
     Fl_Window *sub = [child getFl_Window];
 #if MAC_OS_X_VERSION_MAX_ALLOWED >= MAC_OS_X_VERSION_10_7
     Fl_X *subx = Fl_X::i(sub);
-    bool previous = subx->mapped_to_retina();
+    //bool previous = subx->mapped_to_retina();		// STR #3169 -- unused
     subx->mapped_to_retina( Fl_X::i(parent)->mapped_to_retina() );
 #endif
     rchild.origin = NSMakePoint(pframe.origin.x + sub->x(), pframe.origin.y + parent->h() - (sub->h() + sub->y()));
Index: test/editor.cxx
===================================================================
--- test/editor.cxx	(revision 10486)
+++ test/editor.cxx	(working copy)
@@ -206,7 +206,9 @@
         // Might be a keyword...
 	for (temp = text, bufptr = buf;
 	     (islower((*temp)&255) || *temp == '_') && bufptr < (buf + sizeof(buf) - 1);
-	     *bufptr++ = *temp++);
+	     *bufptr++ = *temp++) {
+	  // nothing
+        }
 
         if (!islower((*temp)&255) && *temp != '_') {
 	  *bufptr = '\0';
Index: test/fracviewer.cxx
===================================================================
--- test/fracviewer.cxx	(revision 10486)
+++ test/fracviewer.cxx	(working copy)
@@ -308,7 +308,7 @@
       Ex    = -EyeDist*sin(TORAD(EyeAz))*cos(TORAD(EyeEl));
       Ey    =  EyeDist*sin(TORAD(EyeEl));
       Ez    =  EyeDist*(cos(TORAD(EyeAz))*cos(TORAD(EyeEl)));
-      EyeAz =  EyeAz;
+      // EyeAz =  EyeAz;	// STR #3169
       EyeEl = -EyeEl;
       EyeMove = INIT_MOVE;
       break;
